==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/yi.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "אויפֿפּאַסן ליגהטבאָקס גאַללאַרי פּאַראַמעטערס");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "אויפֿפּאַסן גאַלערי");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "גאַנץ-גרייס בילד ברייט");
define('MANAGE_GALLERY_FULL_HEIGHT', "גאַנץ-גרייס בילד הויך");
define('MANAGE_GALLERY_THUMB_WIDTH', "טאַמנייל בילד ברייט");
define('MANAGE_GALLERY_THUMB_HEIGHT', "טאַמנייל בילד הויך");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "פּרעסערווע טאַם אַספּעקט ראַטיאָ");
define('MANAGE_GALLERY_SHOW_TITLES', "ווייַזן טיטלעס");
define('MANAGE_GALLERY_DISABLE_SORT', "דיסאַבלע סאָרט");
define('MANAGE_GALLERY_DELETE_IMAGE', "ויסמעקן בילד");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "היט סאָרט סדר");
define('MANAGE_GALLERY_PUBLISH_MSG', "גיט &#39;אַפּדייט&#39; צו אַרויסגעבן <br /> דיין ופּלאָאַדעד בילדער.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "אַלע בילדער האָבן שוין רעסיזעד און סעטטינגס האָבן שוין געזונט.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "עס איז געווען אַ טעות רעסיזינג די בילדער אָדער שפּאָרן סעטטינגס.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "דיין בילד (s) האט שוין ופּלאָאַדעד.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "עס איז געווען אַן טעות ופּלאָאַדינג דיין בילד (ד).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "דער טעקע איר זענען טריינג צו ופּלאָאַד איז נישט אַ בילד.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "דער טעקע איר זענען טריינג צו ופּלאָאַד איז אויך גרויס.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "דער טיטל האט שוין געראטעוועט.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "ביסט איר זיכער איר ווילן צו ויסמעקן בילד");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "די בילד איז געווארן אויסגעמעקט.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "עס איז געווען אַ טעות דיליטינג די בילד.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "זייגער פּאַראַמעטערס און רעסיזינג בילדער, ביטע וואַרטן ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "ופּלאָאַדינג, ביטע וואַרטן ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "די סאָרט סדר האט נישט געווען געזונט. צי איר ווילן צו ראַטעווען די סאָרט סדר?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "די בילד סאָרט סדר האט שוין געראטעוועט.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "עס איז געווען אַ טעות שפּאָרן די בילד סאָרט.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/yi.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "אויפֿפּאַסן ליגהטבאָקס גאַללאַרי פּאַראַמעטערס");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "אויפֿפּאַסן גאַלערי");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "גאַנץ-גרייס בילד ברייט");
define('MANAGE_GALLERY_FULL_HEIGHT', "גאַנץ-גרייס בילד הויך");
define('MANAGE_GALLERY_THUMB_WIDTH', "טאַמנייל בילד ברייט");
define('MANAGE_GALLERY_THUMB_HEIGHT', "טאַמנייל בילד הויך");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "פּרעסערווע טאַם אַספּעקט ראַטיאָ");
define('MANAGE_GALLERY_SHOW_TITLES', "ווייַזן טיטלעס");
define('MANAGE_GALLERY_DISABLE_SORT', "דיסאַבלע סאָרט");
define('MANAGE_GALLERY_DELETE_IMAGE', "ויסמעקן בילד");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "היט סאָרט סדר");
define('MANAGE_GALLERY_PUBLISH_MSG', "גיט &#39;אַפּדייט&#39; צו אַרויסגעבן <br /> דיין ופּלאָאַדעד בילדער.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "אַלע בילדער האָבן שוין רעסיזעד און סעטטינגס האָבן שוין געזונט.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "עס איז געווען אַ טעות רעסיזינג די בילדער אָדער שפּאָרן סעטטינגס.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "דיין בילד (s) האט שוין ופּלאָאַדעד.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "עס איז געווען אַן טעות ופּלאָאַדינג דיין בילד (ד).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "דער טעקע איר זענען טריינג צו ופּלאָאַד איז נישט אַ בילד.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "דער טעקע איר זענען טריינג צו ופּלאָאַד איז אויך גרויס.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "דער טיטל האט שוין געראטעוועט.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "ביסט איר זיכער איר ווילן צו ויסמעקן בילד");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "די בילד איז געווארן אויסגעמעקט.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "עס איז געווען אַ טעות דיליטינג די בילד.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "זייגער פּאַראַמעטערס און רעסיזינג בילדער, ביטע וואַרטן ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "ופּלאָאַדינג, ביטע וואַרטן ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "די סאָרט סדר האט נישט געווען געזונט. צי איר ווילן צו ראַטעווען די סאָרט סדר?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "די בילד סאָרט סדר האט שוין געראטעוועט.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "עס איז געווען אַ טעות שפּאָרן די בילד סאָרט.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "די טעקע איר פרובירט צו צופֿעליקער איז ביגער ווי די PHP סעטטינגס &#39;upload_max_filesize&#39; אָדער די &#39;post_max_size&#39;. קאָנטאַקט דיין סיסטעם אַדמיניסטראַטאָר צו פאַרגרעסערן די לימאַץ.");
?>
